OptionalParserPackState

Enum OptionalParserPackState 

pub enum OptionalParserPackState {
    UnsupportedContainment,
    Absent,
    InstalledDisabled,
    Enabled,
    RollbackReady,
    Stale,
}
Stable content-free lifecycle state.

Variants



UnsupportedContainment

No accepted containment adapter exists on this host.



Absent

No installed slot or project selection exists.



InstalledDisabled

At least one slot is installed but this project is disabled.



Enabled

This project selects a present immutable slot.



RollbackReady

This project selects a present slot and retains a present rollback slot.



Stale

Local selection or slot metadata is malformed, missing, or structurally unsafe.